# Cicada

Welcome to Cicada … a set of tools for working with fault-tolerant secure multiparty computation. Notable Cicada features include:

* Written in Python for simplicity and ease of use.
* Communication inspired by the widely used MPI standard.
* Supports fault tolerance at the application level.
* Highly refined API.

Sound interesting? See the [Tutorial](https://cicada-mpc.readthedocs.io/en/latest/tutorial.html) to get started!

[![Regression tests](https://github.com/cicada-mpc/cicada-mpc/actions/workflows/regression-tests.yml/badge.svg)](https://github.com/cicada-mpc/cicada-mpc/actions/workflows/regression-tests.yml)

[![Coverage Status](https://coveralls.io/repos/github/cicada-mpc/cicada-mpc/badge.svg?branch=main)](https://coveralls.io/github/cicada-mpc/cicada-mpc?branch=main)
